import Taro from '@tarojs/taro'

// 请求选项
interface CloudOptions {
  showLoading?: boolean
  loadingText?: string
  showError?: boolean
}

// 默认选项
const defaultOptions: CloudOptions = {
  showLoading: true,
  loadingText: '加载中...',
  showError: true
}

/**
 * 云函数调用封装
 * @param name 云函数名称
 * @param data 请求数据
 * @param options 请求选项
 */
export async function callCloudFunction<T = any>(
  name: string,
  data?: any,
  options?: CloudOptions
): Promise<T> {
  const opt = { ...defaultOptions, ...options }
  
  // 显示加载中
  if (opt.showLoading) {
    Taro.showLoading({
      title: opt.loadingText || '加载中...'
    })
  }
  
  try {
    // 基于Taro 4.x的调用方式
    const { result } = await Taro.cloud.callFunction({
      name,
      data
    })
    
    // 隐藏加载中
    if (opt.showLoading) {
      Taro.hideLoading()
    }
    
    if (!result) {
      if (opt.showError) {
        Taro.showToast({
          title: '请求失败',
          icon: 'none'
        })
      }
      throw new Error('云函数返回结果为空')
    }
    
    // 业务错误处理 (假设result可能包含error和success字段)
    const typedResult = result as any
    if (typedResult.error || typedResult.success === false) {
      if (opt.showError) {
        Taro.showToast({
          title: typedResult.error || '请求失败',
          icon: 'none'
        })
      }
      throw new Error(typedResult.error || '请求失败')
    }
    
    // 返回data字段或整个result对象
    return (typedResult.data !== undefined ? typedResult.data : typedResult) as T
  } catch (error: any) {
    // 隐藏加载中
    if (opt.showLoading) {
      Taro.hideLoading()
    }
    
    // 显示错误
    if (opt.showError) {
      Taro.showToast({
        title: error.message || '请求异常',
        icon: 'none'
      })
    }
    
    throw error
  }
}