import { defineStore } from 'pinia'
import Taro from '@tarojs/taro'
import { userAPI } from '@/services/api'

export type UserRole = 'player' | 'hoster'

interface UserState {
  role: UserRole
  nickname: string
  avatar: string
  openid: string
  roomId: string | null
  currentGameId: string | null
}

export const useUserStore = defineStore('user', {
  state: (): UserState => ({
    role: 'player', // 默认角色为普通玩家
    nickname: '',
    avatar: '',
    openid: '',
    roomId: null, // 当前房间ID
    currentGameId: null // 当前游戏ID
  }),
  
  actions: {
    // 设置用户角色
    setRole(role: UserRole) {
      this.role = role
      // 保存到本地存储
      Taro.setStorageSync('userRole', role)
    },
    
    // 设置当前游戏
    setCurrentGame(gameId: string | null) {
      this.currentGameId = gameId
    },
    
    // 设置当前房间
    setCurrentRoom(roomId: string | null) {
      this.roomId = roomId
    },
    
    // 获取用户信息
    async getUserInfo() {
      try {
        // 尝试从本地存储获取角色
        const role = Taro.getStorageSync('userRole')
        if (role) {
          this.role = role as UserRole
        }
        
        // 获取用户信息
        const userData = await userAPI.getUserInfo();
        if (userData) {
          this.nickname = userData.nickname || '游客'
          this.avatar = userData.avatar || ''
          this.openid = userData.openid || ''
        }
      } catch (error) {
        console.error('获取用户信息失败:', error)
      }
    },
    
    // 重置用户角色到玩家
    resetToPlayer() {
      this.role = 'player'
      Taro.setStorageSync('userRole', 'player')
    },
    
    // 清除房间和游戏信息
    clearGameSession() {
      this.roomId = null
      this.currentGameId = null
    }
  }
}) 